"""
mesh_to_graphics_edges
======================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class mesh_to_graphics_edges(Operator):
    """Generate edges of surface elements for input mesh

    Parameters
    ----------
    mesh_scoping : Scoping, optional
    include_mid_nodes : bool, optional
    mesh : MeshedRegion


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.mesh.mesh_to_graphics_edges()

    >>> # Make input connections
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_include_mid_nodes = bool()
    >>> op.inputs.include_mid_nodes.connect(my_include_mid_nodes)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.mesh.mesh_to_graphics_edges(
    ...     mesh_scoping=my_mesh_scoping,
    ...     include_mid_nodes=my_include_mid_nodes,
    ...     mesh=my_mesh,
    ... )

    >>> # Get output data
    >>> result_nodes = op.outputs.nodes()
    >>> result_connectivity = op.outputs.connectivity()
    """

    def __init__(
        self,
        mesh_scoping=None,
        include_mid_nodes=None,
        mesh=None,
        config=None,
        server=None,
    ):
        super().__init__(name="mesh_to_graphics_edges", config=config, server=server)
        self._inputs = InputsMeshToGraphicsEdges(self)
        self._outputs = OutputsMeshToGraphicsEdges(self)
        if mesh_scoping is not None:
            self.inputs.mesh_scoping.connect(mesh_scoping)
        if include_mid_nodes is not None:
            self.inputs.include_mid_nodes.connect(include_mid_nodes)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)

    @staticmethod
    def _spec():
        description = """Generate edges of surface elements for input mesh"""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                1: PinSpecification(
                    name="mesh_scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""""",
                ),
                6: PinSpecification(
                    name="include_mid_nodes",
                    type_names=["bool"],
                    optional=True,
                    document="""""",
                ),
                7: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region"],
                    optional=False,
                    document="""""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="nodes",
                    type_names=["field"],
                    optional=False,
                    document="""Node coordinates""",
                ),
                2: PinSpecification(
                    name="connectivity",
                    type_names=["property_field"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="mesh_to_graphics_edges", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsMeshToGraphicsEdges
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsMeshToGraphicsEdges
        """
        return super().outputs


class InputsMeshToGraphicsEdges(_Inputs):
    """Intermediate class used to connect user inputs to
    mesh_to_graphics_edges operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.mesh.mesh_to_graphics_edges()
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_include_mid_nodes = bool()
    >>> op.inputs.include_mid_nodes.connect(my_include_mid_nodes)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    """

    def __init__(self, op: Operator):
        super().__init__(mesh_to_graphics_edges._spec().inputs, op)
        self._mesh_scoping = Input(
            mesh_to_graphics_edges._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._mesh_scoping)
        self._include_mid_nodes = Input(
            mesh_to_graphics_edges._spec().input_pin(6), 6, op, -1
        )
        self._inputs.append(self._include_mid_nodes)
        self._mesh = Input(mesh_to_graphics_edges._spec().input_pin(7), 7, op, -1)
        self._inputs.append(self._mesh)

    @property
    def mesh_scoping(self):
        """Allows to connect mesh_scoping input to the operator.

        Parameters
        ----------
        my_mesh_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.mesh_to_graphics_edges()
        >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
        >>> # or
        >>> op.inputs.mesh_scoping(my_mesh_scoping)
        """
        return self._mesh_scoping

    @property
    def include_mid_nodes(self):
        """Allows to connect include_mid_nodes input to the operator.

        Parameters
        ----------
        my_include_mid_nodes : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.mesh_to_graphics_edges()
        >>> op.inputs.include_mid_nodes.connect(my_include_mid_nodes)
        >>> # or
        >>> op.inputs.include_mid_nodes(my_include_mid_nodes)
        """
        return self._include_mid_nodes

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        Parameters
        ----------
        my_mesh : MeshedRegion

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.mesh_to_graphics_edges()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh


class OutputsMeshToGraphicsEdges(_Outputs):
    """Intermediate class used to get outputs from
    mesh_to_graphics_edges operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.mesh.mesh_to_graphics_edges()
    >>> # Connect inputs : op.inputs. ...
    >>> result_nodes = op.outputs.nodes()
    >>> result_connectivity = op.outputs.connectivity()
    """

    def __init__(self, op: Operator):
        super().__init__(mesh_to_graphics_edges._spec().outputs, op)
        self._nodes = Output(mesh_to_graphics_edges._spec().output_pin(0), 0, op)
        self._outputs.append(self._nodes)
        self._connectivity = Output(mesh_to_graphics_edges._spec().output_pin(2), 2, op)
        self._outputs.append(self._connectivity)

    @property
    def nodes(self):
        """Allows to get nodes output of the operator

        Returns
        ----------
        my_nodes : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.mesh_to_graphics_edges()
        >>> # Connect inputs : op.inputs. ...
        >>> result_nodes = op.outputs.nodes()
        """  # noqa: E501
        return self._nodes

    @property
    def connectivity(self):
        """Allows to get connectivity output of the operator

        Returns
        ----------
        my_connectivity : PropertyField

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.mesh_to_graphics_edges()
        >>> # Connect inputs : op.inputs. ...
        >>> result_connectivity = op.outputs.connectivity()
        """  # noqa: E501
        return self._connectivity



"""
make_sphere_levelset
====================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class make_sphere_levelset(Operator):
    """Computes the level set for a sphere using coordinates.

    Parameters
    ----------
    coordinates : MeshedRegion or Field
    origin : Field
        An overall 3d vector that gives a point of
        the plane.
    radius : float
        Sphere radius.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.mesh.make_sphere_levelset()

    >>> # Make input connections
    >>> my_coordinates = dpf.MeshedRegion()
    >>> op.inputs.coordinates.connect(my_coordinates)
    >>> my_origin = dpf.Field()
    >>> op.inputs.origin.connect(my_origin)
    >>> my_radius = float()
    >>> op.inputs.radius.connect(my_radius)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.mesh.make_sphere_levelset(
    ...     coordinates=my_coordinates,
    ...     origin=my_origin,
    ...     radius=my_radius,
    ... )

    >>> # Get output data
    >>> result_field = op.outputs.field()
    """

    def __init__(
        self, coordinates=None, origin=None, radius=None, config=None, server=None
    ):
        super().__init__(name="levelset::make_sphere", config=config, server=server)
        self._inputs = InputsMakeSphereLevelset(self)
        self._outputs = OutputsMakeSphereLevelset(self)
        if coordinates is not None:
            self.inputs.coordinates.connect(coordinates)
        if origin is not None:
            self.inputs.origin.connect(origin)
        if radius is not None:
            self.inputs.radius.connect(radius)

    @staticmethod
    def _spec():
        description = """Computes the level set for a sphere using coordinates."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="coordinates",
                    type_names=["abstract_meshed_region", "field"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="origin",
                    type_names=["field"],
                    optional=False,
                    document="""An overall 3d vector that gives a point of
        the plane.""",
                ),
                2: PinSpecification(
                    name="radius",
                    type_names=["double"],
                    optional=False,
                    document="""Sphere radius.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="field",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="levelset::make_sphere", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsMakeSphereLevelset
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsMakeSphereLevelset
        """
        return super().outputs


class InputsMakeSphereLevelset(_Inputs):
    """Intermediate class used to connect user inputs to
    make_sphere_levelset operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.mesh.make_sphere_levelset()
    >>> my_coordinates = dpf.MeshedRegion()
    >>> op.inputs.coordinates.connect(my_coordinates)
    >>> my_origin = dpf.Field()
    >>> op.inputs.origin.connect(my_origin)
    >>> my_radius = float()
    >>> op.inputs.radius.connect(my_radius)
    """

    def __init__(self, op: Operator):
        super().__init__(make_sphere_levelset._spec().inputs, op)
        self._coordinates = Input(make_sphere_levelset._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._coordinates)
        self._origin = Input(make_sphere_levelset._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._origin)
        self._radius = Input(make_sphere_levelset._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._radius)

    @property
    def coordinates(self):
        """Allows to connect coordinates input to the operator.

        Parameters
        ----------
        my_coordinates : MeshedRegion or Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.make_sphere_levelset()
        >>> op.inputs.coordinates.connect(my_coordinates)
        >>> # or
        >>> op.inputs.coordinates(my_coordinates)
        """
        return self._coordinates

    @property
    def origin(self):
        """Allows to connect origin input to the operator.

        An overall 3d vector that gives a point of
        the plane.

        Parameters
        ----------
        my_origin : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.make_sphere_levelset()
        >>> op.inputs.origin.connect(my_origin)
        >>> # or
        >>> op.inputs.origin(my_origin)
        """
        return self._origin

    @property
    def radius(self):
        """Allows to connect radius input to the operator.

        Sphere radius.

        Parameters
        ----------
        my_radius : float

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.make_sphere_levelset()
        >>> op.inputs.radius.connect(my_radius)
        >>> # or
        >>> op.inputs.radius(my_radius)
        """
        return self._radius


class OutputsMakeSphereLevelset(_Outputs):
    """Intermediate class used to get outputs from
    make_sphere_levelset operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.mesh.make_sphere_levelset()
    >>> # Connect inputs : op.inputs. ...
    >>> result_field = op.outputs.field()
    """

    def __init__(self, op: Operator):
        super().__init__(make_sphere_levelset._spec().outputs, op)
        self._field = Output(make_sphere_levelset._spec().output_pin(0), 0, op)
        self._outputs.append(self._field)

    @property
    def field(self):
        """Allows to get field output of the operator

        Returns
        ----------
        my_field : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.make_sphere_levelset()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field = op.outputs.field()
        """  # noqa: E501
        return self._field



"""
nodal_extend_to_mid_nodes
=========================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class nodal_extend_to_mid_nodes(Operator):
    """Extends a Nodal field defined on corner nodes to a field defined also
    on mid nodes.

    Parameters
    ----------
    field : Field or FieldsContainer
        Field or fields container with only one field
        is expected
    node_scoping : Scoping, optional
        Nodes expected in output.
    element_scoping : Scoping, optional
        Precomputed list of elements of interest
        (improves performances).
    mesh : MeshedRegion, optional


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes()

    >>> # Make input connections
    >>> my_field = dpf.Field()
    >>> op.inputs.field.connect(my_field)
    >>> my_node_scoping = dpf.Scoping()
    >>> op.inputs.node_scoping.connect(my_node_scoping)
    >>> my_element_scoping = dpf.Scoping()
    >>> op.inputs.element_scoping.connect(my_element_scoping)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes(
    ...     field=my_field,
    ...     node_scoping=my_node_scoping,
    ...     element_scoping=my_element_scoping,
    ...     mesh=my_mesh,
    ... )

    >>> # Get output data
    >>> result_field = op.outputs.field()
    """

    def __init__(
        self,
        field=None,
        node_scoping=None,
        element_scoping=None,
        mesh=None,
        config=None,
        server=None,
    ):
        super().__init__(name="nodal_extend_to_mid_nodes", config=config, server=server)
        self._inputs = InputsNodalExtendToMidNodes(self)
        self._outputs = OutputsNodalExtendToMidNodes(self)
        if field is not None:
            self.inputs.field.connect(field)
        if node_scoping is not None:
            self.inputs.node_scoping.connect(node_scoping)
        if element_scoping is not None:
            self.inputs.element_scoping.connect(element_scoping)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)

    @staticmethod
    def _spec():
        description = """Extends a Nodal field defined on corner nodes to a field defined also
            on mid nodes."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="field",
                    type_names=["field", "fields_container"],
                    optional=False,
                    document="""Field or fields container with only one field
        is expected""",
                ),
                1: PinSpecification(
                    name="node_scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""Nodes expected in output.""",
                ),
                5: PinSpecification(
                    name="element_scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""Precomputed list of elements of interest
        (improves performances).""",
                ),
                7: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region"],
                    optional=True,
                    document="""""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="field",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="nodal_extend_to_mid_nodes", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsNodalExtendToMidNodes
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsNodalExtendToMidNodes
        """
        return super().outputs


class InputsNodalExtendToMidNodes(_Inputs):
    """Intermediate class used to connect user inputs to
    nodal_extend_to_mid_nodes operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes()
    >>> my_field = dpf.Field()
    >>> op.inputs.field.connect(my_field)
    >>> my_node_scoping = dpf.Scoping()
    >>> op.inputs.node_scoping.connect(my_node_scoping)
    >>> my_element_scoping = dpf.Scoping()
    >>> op.inputs.element_scoping.connect(my_element_scoping)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    """

    def __init__(self, op: Operator):
        super().__init__(nodal_extend_to_mid_nodes._spec().inputs, op)
        self._field = Input(nodal_extend_to_mid_nodes._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._field)
        self._node_scoping = Input(
            nodal_extend_to_mid_nodes._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._node_scoping)
        self._element_scoping = Input(
            nodal_extend_to_mid_nodes._spec().input_pin(5), 5, op, -1
        )
        self._inputs.append(self._element_scoping)
        self._mesh = Input(nodal_extend_to_mid_nodes._spec().input_pin(7), 7, op, -1)
        self._inputs.append(self._mesh)

    @property
    def field(self):
        """Allows to connect field input to the operator.

        Field or fields container with only one field
        is expected

        Parameters
        ----------
        my_field : Field or FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes()
        >>> op.inputs.field.connect(my_field)
        >>> # or
        >>> op.inputs.field(my_field)
        """
        return self._field

    @property
    def node_scoping(self):
        """Allows to connect node_scoping input to the operator.

        Nodes expected in output.

        Parameters
        ----------
        my_node_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes()
        >>> op.inputs.node_scoping.connect(my_node_scoping)
        >>> # or
        >>> op.inputs.node_scoping(my_node_scoping)
        """
        return self._node_scoping

    @property
    def element_scoping(self):
        """Allows to connect element_scoping input to the operator.

        Precomputed list of elements of interest
        (improves performances).

        Parameters
        ----------
        my_element_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes()
        >>> op.inputs.element_scoping.connect(my_element_scoping)
        >>> # or
        >>> op.inputs.element_scoping(my_element_scoping)
        """
        return self._element_scoping

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        Parameters
        ----------
        my_mesh : MeshedRegion

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh


class OutputsNodalExtendToMidNodes(_Outputs):
    """Intermediate class used to get outputs from
    nodal_extend_to_mid_nodes operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes()
    >>> # Connect inputs : op.inputs. ...
    >>> result_field = op.outputs.field()
    """

    def __init__(self, op: Operator):
        super().__init__(nodal_extend_to_mid_nodes._spec().outputs, op)
        self._field = Output(nodal_extend_to_mid_nodes._spec().output_pin(0), 0, op)
        self._outputs.append(self._field)

    @property
    def field(self):
        """Allows to get field output of the operator

        Returns
        ----------
        my_field : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.nodal_extend_to_mid_nodes()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field = op.outputs.field()
        """  # noqa: E501
        return self._field



"""
property_field_provider_by_name
===============================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class property_field_provider_by_name(Operator):
    """Provides the property values for a set of elements for a defined
    property name.

    Parameters
    ----------
    mesh_scoping : Scoping, optional
        Scoping that defines the set of elements to
        fetch the property values for. if not
        specified, applied on all the
        elements of the mesh.
    streams_container : StreamsContainer, optional
        Optional if using a datasources
    data_sources : DataSources
        Optional if using a streamscontainer
    property_name : str
        Property to read, that can be the following:
        elements_connectivity,
        nodes_connectivity, material,
        element_type, mapdl_element_type,
        mapdl_element_type_id harmonic_index,
        step, substep, keyopt_i (i = 1 ->
        18).


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.metadata.property_field_provider_by_name()

    >>> # Make input connections
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_property_name = str()
    >>> op.inputs.property_name.connect(my_property_name)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.metadata.property_field_provider_by_name(
    ...     mesh_scoping=my_mesh_scoping,
    ...     streams_container=my_streams_container,
    ...     data_sources=my_data_sources,
    ...     property_name=my_property_name,
    ... )

    >>> # Get output data
    >>> result_property_field = op.outputs.property_field()
    """

    def __init__(
        self,
        mesh_scoping=None,
        streams_container=None,
        data_sources=None,
        property_name=None,
        config=None,
        server=None,
    ):
        super().__init__(
            name="property_field_provider_by_name", config=config, server=server
        )
        self._inputs = InputsPropertyFieldProviderByName(self)
        self._outputs = OutputsPropertyFieldProviderByName(self)
        if mesh_scoping is not None:
            self.inputs.mesh_scoping.connect(mesh_scoping)
        if streams_container is not None:
            self.inputs.streams_container.connect(streams_container)
        if data_sources is not None:
            self.inputs.data_sources.connect(data_sources)
        if property_name is not None:
            self.inputs.property_name.connect(property_name)

    @staticmethod
    def _spec():
        description = """Provides the property values for a set of elements for a defined
            property name."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                1: PinSpecification(
                    name="mesh_scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""Scoping that defines the set of elements to
        fetch the property values for. if not
        specified, applied on all the
        elements of the mesh.""",
                ),
                3: PinSpecification(
                    name="streams_container",
                    type_names=["streams_container"],
                    optional=True,
                    document="""Optional if using a datasources""",
                ),
                4: PinSpecification(
                    name="data_sources",
                    type_names=["data_sources"],
                    optional=False,
                    document="""Optional if using a streamscontainer""",
                ),
                13: PinSpecification(
                    name="property_name",
                    type_names=["string"],
                    optional=False,
                    document="""Property to read, that can be the following:
        elements_connectivity,
        nodes_connectivity, material,
        element_type, mapdl_element_type,
        mapdl_element_type_id harmonic_index,
        step, substep, keyopt_i (i = 1 ->
        18).""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="property_field",
                    type_names=["property_field"],
                    optional=False,
                    document="""Property field""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(
            name="property_field_provider_by_name", server=server
        )

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsPropertyFieldProviderByName
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsPropertyFieldProviderByName
        """
        return super().outputs


class InputsPropertyFieldProviderByName(_Inputs):
    """Intermediate class used to connect user inputs to
    property_field_provider_by_name operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.metadata.property_field_provider_by_name()
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_property_name = str()
    >>> op.inputs.property_name.connect(my_property_name)
    """

    def __init__(self, op: Operator):
        super().__init__(property_field_provider_by_name._spec().inputs, op)
        self._mesh_scoping = Input(
            property_field_provider_by_name._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._mesh_scoping)
        self._streams_container = Input(
            property_field_provider_by_name._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._streams_container)
        self._data_sources = Input(
            property_field_provider_by_name._spec().input_pin(4), 4, op, -1
        )
        self._inputs.append(self._data_sources)
        self._property_name = Input(
            property_field_provider_by_name._spec().input_pin(13), 13, op, -1
        )
        self._inputs.append(self._property_name)

    @property
    def mesh_scoping(self):
        """Allows to connect mesh_scoping input to the operator.

        Scoping that defines the set of elements to
        fetch the property values for. if not
        specified, applied on all the
        elements of the mesh.

        Parameters
        ----------
        my_mesh_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.property_field_provider_by_name()
        >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
        >>> # or
        >>> op.inputs.mesh_scoping(my_mesh_scoping)
        """
        return self._mesh_scoping

    @property
    def streams_container(self):
        """Allows to connect streams_container input to the operator.

        Optional if using a datasources

        Parameters
        ----------
        my_streams_container : StreamsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.property_field_provider_by_name()
        >>> op.inputs.streams_container.connect(my_streams_container)
        >>> # or
        >>> op.inputs.streams_container(my_streams_container)
        """
        return self._streams_container

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator.

        Optional if using a streamscontainer

        Parameters
        ----------
        my_data_sources : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.property_field_provider_by_name()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> # or
        >>> op.inputs.data_sources(my_data_sources)
        """
        return self._data_sources

    @property
    def property_name(self):
        """Allows to connect property_name input to the operator.

        Property to read, that can be the following:
        elements_connectivity,
        nodes_connectivity, material,
        element_type, mapdl_element_type,
        mapdl_element_type_id harmonic_index,
        step, substep, keyopt_i (i = 1 ->
        18).

        Parameters
        ----------
        my_property_name : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.property_field_provider_by_name()
        >>> op.inputs.property_name.connect(my_property_name)
        >>> # or
        >>> op.inputs.property_name(my_property_name)
        """
        return self._property_name


class OutputsPropertyFieldProviderByName(_Outputs):
    """Intermediate class used to get outputs from
    property_field_provider_by_name operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.metadata.property_field_provider_by_name()
    >>> # Connect inputs : op.inputs. ...
    >>> result_property_field = op.outputs.property_field()
    """

    def __init__(self, op: Operator):
        super().__init__(property_field_provider_by_name._spec().outputs, op)
        self._property_field = Output(
            property_field_provider_by_name._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._property_field)

    @property
    def property_field(self):
        """Allows to get property_field output of the operator

        Returns
        ----------
        my_property_field : PropertyField

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.property_field_provider_by_name()
        >>> # Connect inputs : op.inputs. ...
        >>> result_property_field = op.outputs.property_field()
        """  # noqa: E501
        return self._property_field



"""
cms_matrices_provider
=====================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class cms_matrices_provider(Operator):
    """Read reduced matrices for cms elements. Extract stiffness, damping,
    mass matrices and load vector from a subfile.

    Parameters
    ----------
    data_sources : DataSources
        Data_sources (must contain at list one
        subfile).
    matrix_form : bool
        If this pin i set to true, data are return as
        matrix form.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.result.cms_matrices_provider()

    >>> # Make input connections
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_matrix_form = bool()
    >>> op.inputs.matrix_form.connect(my_matrix_form)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.result.cms_matrices_provider(
    ...     data_sources=my_data_sources,
    ...     matrix_form=my_matrix_form,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, data_sources=None, matrix_form=None, config=None, server=None):
        super().__init__(name="cms_matrices_provider", config=config, server=server)
        self._inputs = InputsCmsMatricesProvider(self)
        self._outputs = OutputsCmsMatricesProvider(self)
        if data_sources is not None:
            self.inputs.data_sources.connect(data_sources)
        if matrix_form is not None:
            self.inputs.matrix_form.connect(matrix_form)

    @staticmethod
    def _spec():
        description = """Read reduced matrices for cms elements. Extract stiffness, damping,
            mass matrices and load vector from a subfile."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                4: PinSpecification(
                    name="data_sources",
                    type_names=["data_sources"],
                    optional=False,
                    document="""Data_sources (must contain at list one
        subfile).""",
                ),
                200: PinSpecification(
                    name="matrix_form",
                    type_names=["bool"],
                    optional=False,
                    document="""If this pin i set to true, data are return as
        matrix form.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""Fields container containing in this order :
        stiffness, damping, mass matrices,
        and then load vector. but if pin 200
        is set to true, it's in matrix form.""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="cms_matrices_provider", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsCmsMatricesProvider
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsCmsMatricesProvider
        """
        return super().outputs


class InputsCmsMatricesProvider(_Inputs):
    """Intermediate class used to connect user inputs to
    cms_matrices_provider operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.cms_matrices_provider()
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_matrix_form = bool()
    >>> op.inputs.matrix_form.connect(my_matrix_form)
    """

    def __init__(self, op: Operator):
        super().__init__(cms_matrices_provider._spec().inputs, op)
        self._data_sources = Input(
            cms_matrices_provider._spec().input_pin(4), 4, op, -1
        )
        self._inputs.append(self._data_sources)
        self._matrix_form = Input(
            cms_matrices_provider._spec().input_pin(200), 200, op, -1
        )
        self._inputs.append(self._matrix_form)

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator.

        Data_sources (must contain at list one
        subfile).

        Parameters
        ----------
        my_data_sources : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cms_matrices_provider()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> # or
        >>> op.inputs.data_sources(my_data_sources)
        """
        return self._data_sources

    @property
    def matrix_form(self):
        """Allows to connect matrix_form input to the operator.

        If this pin i set to true, data are return as
        matrix form.

        Parameters
        ----------
        my_matrix_form : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cms_matrices_provider()
        >>> op.inputs.matrix_form.connect(my_matrix_form)
        >>> # or
        >>> op.inputs.matrix_form(my_matrix_form)
        """
        return self._matrix_form


class OutputsCmsMatricesProvider(_Outputs):
    """Intermediate class used to get outputs from
    cms_matrices_provider operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.cms_matrices_provider()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(cms_matrices_provider._spec().outputs, op)
        self._fields_container = Output(
            cms_matrices_provider._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cms_matrices_provider()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container



"""
tri_mesh_skin
=============
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class tri_mesh_skin(Operator):
    """Extracts a skin of the mesh in triangles in a new meshed region.

    Parameters
    ----------
    mesh : MeshedRegion
    include_surfaces : bool, optional
        True: meshing will also take into account
        shell and skin elements. false:
        meshing will ignore shell and skin
        elements. the default is false.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.mesh.tri_mesh_skin()

    >>> # Make input connections
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_include_surfaces = bool()
    >>> op.inputs.include_surfaces.connect(my_include_surfaces)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.mesh.tri_mesh_skin(
    ...     mesh=my_mesh,
    ...     include_surfaces=my_include_surfaces,
    ... )

    >>> # Get output data
    >>> result_mesh = op.outputs.mesh()
    >>> result_nodes_mesh_scoping = op.outputs.nodes_mesh_scoping()
    """

    def __init__(self, mesh=None, include_surfaces=None, config=None, server=None):
        super().__init__(
            name="meshed_skin_sector_triangle", config=config, server=server
        )
        self._inputs = InputsTriMeshSkin(self)
        self._outputs = OutputsTriMeshSkin(self)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)
        if include_surfaces is not None:
            self.inputs.include_surfaces.connect(include_surfaces)

    @staticmethod
    def _spec():
        description = (
            """Extracts a skin of the mesh in triangles in a new meshed region."""
        )
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="include_surfaces",
                    type_names=["bool"],
                    optional=True,
                    document="""True: meshing will also take into account
        shell and skin elements. false:
        meshing will ignore shell and skin
        elements. the default is false.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="nodes_mesh_scoping",
                    type_names=["scoping"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(
            name="meshed_skin_sector_triangle", server=server
        )

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsTriMeshSkin
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsTriMeshSkin
        """
        return super().outputs


class InputsTriMeshSkin(_Inputs):
    """Intermediate class used to connect user inputs to
    tri_mesh_skin operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.mesh.tri_mesh_skin()
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_include_surfaces = bool()
    >>> op.inputs.include_surfaces.connect(my_include_surfaces)
    """

    def __init__(self, op: Operator):
        super().__init__(tri_mesh_skin._spec().inputs, op)
        self._mesh = Input(tri_mesh_skin._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._mesh)
        self._include_surfaces = Input(tri_mesh_skin._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._include_surfaces)

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        Parameters
        ----------
        my_mesh : MeshedRegion

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.tri_mesh_skin()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh

    @property
    def include_surfaces(self):
        """Allows to connect include_surfaces input to the operator.

        True: meshing will also take into account
        shell and skin elements. false:
        meshing will ignore shell and skin
        elements. the default is false.

        Parameters
        ----------
        my_include_surfaces : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.tri_mesh_skin()
        >>> op.inputs.include_surfaces.connect(my_include_surfaces)
        >>> # or
        >>> op.inputs.include_surfaces(my_include_surfaces)
        """
        return self._include_surfaces


class OutputsTriMeshSkin(_Outputs):
    """Intermediate class used to get outputs from
    tri_mesh_skin operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.mesh.tri_mesh_skin()
    >>> # Connect inputs : op.inputs. ...
    >>> result_mesh = op.outputs.mesh()
    >>> result_nodes_mesh_scoping = op.outputs.nodes_mesh_scoping()
    """

    def __init__(self, op: Operator):
        super().__init__(tri_mesh_skin._spec().outputs, op)
        self._mesh = Output(tri_mesh_skin._spec().output_pin(0), 0, op)
        self._outputs.append(self._mesh)
        self._nodes_mesh_scoping = Output(tri_mesh_skin._spec().output_pin(1), 1, op)
        self._outputs.append(self._nodes_mesh_scoping)

    @property
    def mesh(self):
        """Allows to get mesh output of the operator

        Returns
        ----------
        my_mesh : MeshedRegion

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.tri_mesh_skin()
        >>> # Connect inputs : op.inputs. ...
        >>> result_mesh = op.outputs.mesh()
        """  # noqa: E501
        return self._mesh

    @property
    def nodes_mesh_scoping(self):
        """Allows to get nodes_mesh_scoping output of the operator

        Returns
        ----------
        my_nodes_mesh_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.mesh.tri_mesh_skin()
        >>> # Connect inputs : op.inputs. ...
        >>> result_nodes_mesh_scoping = op.outputs.nodes_mesh_scoping()
        """  # noqa: E501
        return self._nodes_mesh_scoping



"""
rescope_fc
==========
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class rescope_fc(Operator):
    """Rescopes a field on the given scoping. If an ID does not exist in the
    original field, the default value (in 2) is used when defined.

    Parameters
    ----------
    fields_container : FieldsContainer
    mesh_scoping : Scoping
    default_value : float, optional
        If pin 2 is used, the ids not found in the
        fields are added with this default
        value.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.scoping.rescope_fc()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_default_value = float()
    >>> op.inputs.default_value.connect(my_default_value)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.scoping.rescope_fc(
    ...     fields_container=my_fields_container,
    ...     mesh_scoping=my_mesh_scoping,
    ...     default_value=my_default_value,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(
        self,
        fields_container=None,
        mesh_scoping=None,
        default_value=None,
        config=None,
        server=None,
    ):
        super().__init__(name="Rescope_fc", config=config, server=server)
        self._inputs = InputsRescopeFc(self)
        self._outputs = OutputsRescopeFc(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if mesh_scoping is not None:
            self.inputs.mesh_scoping.connect(mesh_scoping)
        if default_value is not None:
            self.inputs.default_value.connect(default_value)

    @staticmethod
    def _spec():
        description = """Rescopes a field on the given scoping. If an ID does not exist in the
            original field, the default value (in 2) is used when
            defined."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="mesh_scoping",
                    type_names=["scoping", "vector<int32>"],
                    optional=False,
                    document="""""",
                ),
                2: PinSpecification(
                    name="default_value",
                    type_names=["double", "vector<double>"],
                    optional=True,
                    document="""If pin 2 is used, the ids not found in the
        fields are added with this default
        value.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="Rescope_fc", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsRescopeFc
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsRescopeFc
        """
        return super().outputs


class InputsRescopeFc(_Inputs):
    """Intermediate class used to connect user inputs to
    rescope_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.scoping.rescope_fc()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_default_value = float()
    >>> op.inputs.default_value.connect(my_default_value)
    """

    def __init__(self, op: Operator):
        super().__init__(rescope_fc._spec().inputs, op)
        self._fields_container = Input(rescope_fc._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._fields_container)
        self._mesh_scoping = Input(rescope_fc._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._mesh_scoping)
        self._default_value = Input(rescope_fc._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._default_value)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.scoping.rescope_fc()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def mesh_scoping(self):
        """Allows to connect mesh_scoping input to the operator.

        Parameters
        ----------
        my_mesh_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.scoping.rescope_fc()
        >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
        >>> # or
        >>> op.inputs.mesh_scoping(my_mesh_scoping)
        """
        return self._mesh_scoping

    @property
    def default_value(self):
        """Allows to connect default_value input to the operator.

        If pin 2 is used, the ids not found in the
        fields are added with this default
        value.

        Parameters
        ----------
        my_default_value : float

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.scoping.rescope_fc()
        >>> op.inputs.default_value.connect(my_default_value)
        >>> # or
        >>> op.inputs.default_value(my_default_value)
        """
        return self._default_value


class OutputsRescopeFc(_Outputs):
    """Intermediate class used to get outputs from
    rescope_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.scoping.rescope_fc()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(rescope_fc._spec().outputs, op)
        self._fields_container = Output(rescope_fc._spec().output_pin(0), 0, op)
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.scoping.rescope_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container



"""
min_max_over_label_fc
=====================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class min_max_over_label_fc(Operator):
    """Create two fields (0 min 1 max) by looping over the fields container
    in input and taking the min/max value by component through all the
    fields having the same id for the label set in input (in pin 1).
    If no label is specified or if the specified label doesn't exist,
    the operation is done over all the fields. The fields out are
    located on the label set in input, so their scoping are the labels
    ids.For each min max value, the label id for one other fields
    container labels is kept and returned in a scoping in pin 2 (min)
    and 3 (max).The field's scoping ids of the value kept in min max
    are also returned in the scopings in pin 4 (min) and 5 (max).

    Parameters
    ----------
    fields_container : FieldsContainer
    label : str
        Label name from the fields container


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.min_max.min_max_over_label_fc()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_label = str()
    >>> op.inputs.label.connect(my_label)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.min_max.min_max_over_label_fc(
    ...     fields_container=my_fields_container,
    ...     label=my_label,
    ... )

    >>> # Get output data
    >>> result_field_min = op.outputs.field_min()
    >>> result_field_max = op.outputs.field_max()
    >>> result_domain_ids_min = op.outputs.domain_ids_min()
    >>> result_domain_ids_max = op.outputs.domain_ids_max()
    >>> result_scoping_ids_min = op.outputs.scoping_ids_min()
    >>> result_scoping_ids_max = op.outputs.scoping_ids_max()
    """

    def __init__(self, fields_container=None, label=None, config=None, server=None):
        super().__init__(name="min_max_over_label_fc", config=config, server=server)
        self._inputs = InputsMinMaxOverLabelFc(self)
        self._outputs = OutputsMinMaxOverLabelFc(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if label is not None:
            self.inputs.label.connect(label)

    @staticmethod
    def _spec():
        description = """Create two fields (0 min 1 max) by looping over the fields container
            in input and taking the min/max value by component through
            all the fields having the same id for the label set in
            input (in pin 1). If no label is specified or if the
            specified label doesn't exist, the operation is done over
            all the fields. The fields out are located on the label
            set in input, so their scoping are the labels ids.For each
            min max value, the label id for one other fields container
            labels is kept and returned in a scoping in pin 2 (min)
            and 3 (max).The field's scoping ids of the value kept in
            min max are also returned in the scopings in pin 4 (min)
            and 5 (max)."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="label",
                    type_names=["string"],
                    optional=False,
                    document="""Label name from the fields container""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="field_min",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="field_max",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
                2: PinSpecification(
                    name="domain_ids_min",
                    type_names=["scoping"],
                    optional=True,
                    document="""""",
                ),
                3: PinSpecification(
                    name="domain_ids_max",
                    type_names=["scoping"],
                    optional=True,
                    document="""""",
                ),
                4: PinSpecification(
                    name="scoping_ids_min",
                    type_names=["scoping"],
                    optional=False,
                    document="""""",
                ),
                5: PinSpecification(
                    name="scoping_ids_max",
                    type_names=["scoping"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="min_max_over_label_fc", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsMinMaxOverLabelFc
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsMinMaxOverLabelFc
        """
        return super().outputs


class InputsMinMaxOverLabelFc(_Inputs):
    """Intermediate class used to connect user inputs to
    min_max_over_label_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.min_max.min_max_over_label_fc()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_label = str()
    >>> op.inputs.label.connect(my_label)
    """

    def __init__(self, op: Operator):
        super().__init__(min_max_over_label_fc._spec().inputs, op)
        self._fields_container = Input(
            min_max_over_label_fc._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._fields_container)
        self._label = Input(min_max_over_label_fc._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._label)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.min_max.min_max_over_label_fc()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def label(self):
        """Allows to connect label input to the operator.

        Label name from the fields container

        Parameters
        ----------
        my_label : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.min_max.min_max_over_label_fc()
        >>> op.inputs.label.connect(my_label)
        >>> # or
        >>> op.inputs.label(my_label)
        """
        return self._label


class OutputsMinMaxOverLabelFc(_Outputs):
    """Intermediate class used to get outputs from
    min_max_over_label_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.min_max.min_max_over_label_fc()
    >>> # Connect inputs : op.inputs. ...
    >>> result_field_min = op.outputs.field_min()
    >>> result_field_max = op.outputs.field_max()
    >>> result_domain_ids_min = op.outputs.domain_ids_min()
    >>> result_domain_ids_max = op.outputs.domain_ids_max()
    >>> result_scoping_ids_min = op.outputs.scoping_ids_min()
    >>> result_scoping_ids_max = op.outputs.scoping_ids_max()
    """

    def __init__(self, op: Operator):
        super().__init__(min_max_over_label_fc._spec().outputs, op)
        self._field_min = Output(min_max_over_label_fc._spec().output_pin(0), 0, op)
        self._outputs.append(self._field_min)
        self._field_max = Output(min_max_over_label_fc._spec().output_pin(1), 1, op)
        self._outputs.append(self._field_max)
        self._domain_ids_min = Output(
            min_max_over_label_fc._spec().output_pin(2), 2, op
        )
        self._outputs.append(self._domain_ids_min)
        self._domain_ids_max = Output(
            min_max_over_label_fc._spec().output_pin(3), 3, op
        )
        self._outputs.append(self._domain_ids_max)
        self._scoping_ids_min = Output(
            min_max_over_label_fc._spec().output_pin(4), 4, op
        )
        self._outputs.append(self._scoping_ids_min)
        self._scoping_ids_max = Output(
            min_max_over_label_fc._spec().output_pin(5), 5, op
        )
        self._outputs.append(self._scoping_ids_max)

    @property
    def field_min(self):
        """Allows to get field_min output of the operator

        Returns
        ----------
        my_field_min : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.min_max.min_max_over_label_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field_min = op.outputs.field_min()
        """  # noqa: E501
        return self._field_min

    @property
    def field_max(self):
        """Allows to get field_max output of the operator

        Returns
        ----------
        my_field_max : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.min_max.min_max_over_label_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field_max = op.outputs.field_max()
        """  # noqa: E501
        return self._field_max

    @property
    def domain_ids_min(self):
        """Allows to get domain_ids_min output of the operator

        Returns
        ----------
        my_domain_ids_min : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.min_max.min_max_over_label_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_domain_ids_min = op.outputs.domain_ids_min()
        """  # noqa: E501
        return self._domain_ids_min

    @property
    def domain_ids_max(self):
        """Allows to get domain_ids_max output of the operator

        Returns
        ----------
        my_domain_ids_max : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.min_max.min_max_over_label_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_domain_ids_max = op.outputs.domain_ids_max()
        """  # noqa: E501
        return self._domain_ids_max

    @property
    def scoping_ids_min(self):
        """Allows to get scoping_ids_min output of the operator

        Returns
        ----------
        my_scoping_ids_min : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.min_max.min_max_over_label_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_scoping_ids_min = op.outputs.scoping_ids_min()
        """  # noqa: E501
        return self._scoping_ids_min

    @property
    def scoping_ids_max(self):
        """Allows to get scoping_ids_max output of the operator

        Returns
        ----------
        my_scoping_ids_max : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.min_max.min_max_over_label_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_scoping_ids_max = op.outputs.scoping_ids_max()
        """  # noqa: E501
        return self._scoping_ids_max



from .abc_weightings import abc_weightings 
from .field_band_pass import field_band_pass 
from .field_band_pass_fc import field_band_pass_fc 
from .field_high_pass import field_high_pass 
from .field_high_pass_fc import field_high_pass_fc 
from .field_low_pass import field_low_pass 
from .field_low_pass_fc import field_low_pass_fc 
from .field_signed_high_pass import field_signed_high_pass 
from .field_signed_high_pass_fc import field_signed_high_pass_fc 
from .scoping_band_pass import scoping_band_pass 
from .scoping_high_pass import scoping_high_pass 
from .scoping_low_pass import scoping_low_pass 
from .scoping_signed_high_pass import scoping_signed_high_pass 
from .timefreq_band_pass import timefreq_band_pass 
from .timefreq_high_pass import timefreq_high_pass 
from .timefreq_low_pass import timefreq_low_pass 
from .timefreq_signed_high_pass import timefreq_signed_high_pass 
from .timescoping_band_pass import timescoping_band_pass 
from .timescoping_high_pass import timescoping_high_pass 
from .timescoping_low_pass import timescoping_low_pass 
from .timescoping_signed_high_pass import timescoping_signed_high_pass 



"""
elemental_to_nodal
==================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class elemental_to_nodal(Operator):
    """Transforms an Elemental field to a Nodal field. The result is computed
    on a given node's scoping.  1. For a finite element mesh, the
    value on a node is the average of the values of the neighbour
    elements.  2. For a volume finite volume mesh, the agorithm is :
    - For each node, compute interpolation weights for the cells
    connected to it based   on the Frink's Laplacian method.         -
    If the determinant of the I matrix is zero, switch to an inverse
    distance weighted average.         - If not, compute the Frink
    weights and apply the Holmes' weight clip.         - If the
    clipping produces a large overshoot, inverse volume weighted
    average is used.. 3. For a face finite volume mesh inverse
    distance weighted average is used.

    Parameters
    ----------
    field : Field or FieldsContainer
        Field or fields container with only one field
        is expected
    mesh_scoping : Scoping, optional
    force_averaging : int, optional
        Averaging on nodes is used if this pin is set
        to 1 (default is 1 for integrated
        results and 0 for discrete ones).
    algorithm : int, optional
        Forces the usage of algorithm 1, 2 or 3
        (default is chosen based on the type
        of mesh).


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.averaging.elemental_to_nodal()

    >>> # Make input connections
    >>> my_field = dpf.Field()
    >>> op.inputs.field.connect(my_field)
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_force_averaging = int()
    >>> op.inputs.force_averaging.connect(my_force_averaging)
    >>> my_algorithm = int()
    >>> op.inputs.algorithm.connect(my_algorithm)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.averaging.elemental_to_nodal(
    ...     field=my_field,
    ...     mesh_scoping=my_mesh_scoping,
    ...     force_averaging=my_force_averaging,
    ...     algorithm=my_algorithm,
    ... )

    >>> # Get output data
    >>> result_field = op.outputs.field()
    """

    def __init__(
        self,
        field=None,
        mesh_scoping=None,
        force_averaging=None,
        algorithm=None,
        config=None,
        server=None,
    ):
        super().__init__(name="elemental_to_nodal", config=config, server=server)
        self._inputs = InputsElementalToNodal(self)
        self._outputs = OutputsElementalToNodal(self)
        if field is not None:
            self.inputs.field.connect(field)
        if mesh_scoping is not None:
            self.inputs.mesh_scoping.connect(mesh_scoping)
        if force_averaging is not None:
            self.inputs.force_averaging.connect(force_averaging)
        if algorithm is not None:
            self.inputs.algorithm.connect(algorithm)

    @staticmethod
    def _spec():
        description = """Transforms an Elemental field to a Nodal field. The result is computed
            on a given node's scoping.  1. For a finite element mesh,
            the value on a node is the average of the values of the
            neighbour elements.  2. For a volume finite volume mesh,
            the agorithm is :    - For each node, compute
            interpolation weights for the cells connected to it based
            on the Frink's Laplacian method.         - If the
            determinant of the I matrix is zero, switch to an inverse
            distance weighted average.         - If not, compute the
            Frink weights and apply the Holmes' weight clip.         -
            If the clipping produces a large overshoot, inverse volume
            weighted average is used.. 3. For a face finite volume
            mesh inverse distance weighted average is used."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="field",
                    type_names=["field", "fields_container"],
                    optional=False,
                    document="""Field or fields container with only one field
        is expected""",
                ),
                1: PinSpecification(
                    name="mesh_scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""""",
                ),
                2: PinSpecification(
                    name="force_averaging",
                    type_names=["int32"],
                    optional=True,
                    document="""Averaging on nodes is used if this pin is set
        to 1 (default is 1 for integrated
        results and 0 for discrete ones).""",
                ),
                200: PinSpecification(
                    name="algorithm",
                    type_names=["int32"],
                    optional=True,
                    document="""Forces the usage of algorithm 1, 2 or 3
        (default is chosen based on the type
        of mesh).""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="field",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="elemental_to_nodal", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsElementalToNodal
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsElementalToNodal
        """
        return super().outputs


class InputsElementalToNodal(_Inputs):
    """Intermediate class used to connect user inputs to
    elemental_to_nodal operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.elemental_to_nodal()
    >>> my_field = dpf.Field()
    >>> op.inputs.field.connect(my_field)
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_force_averaging = int()
    >>> op.inputs.force_averaging.connect(my_force_averaging)
    >>> my_algorithm = int()
    >>> op.inputs.algorithm.connect(my_algorithm)
    """

    def __init__(self, op: Operator):
        super().__init__(elemental_to_nodal._spec().inputs, op)
        self._field = Input(elemental_to_nodal._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._field)
        self._mesh_scoping = Input(elemental_to_nodal._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._mesh_scoping)
        self._force_averaging = Input(
            elemental_to_nodal._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._force_averaging)
        self._algorithm = Input(elemental_to_nodal._spec().input_pin(200), 200, op, -1)
        self._inputs.append(self._algorithm)

    @property
    def field(self):
        """Allows to connect field input to the operator.

        Field or fields container with only one field
        is expected

        Parameters
        ----------
        my_field : Field or FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal()
        >>> op.inputs.field.connect(my_field)
        >>> # or
        >>> op.inputs.field(my_field)
        """
        return self._field

    @property
    def mesh_scoping(self):
        """Allows to connect mesh_scoping input to the operator.

        Parameters
        ----------
        my_mesh_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal()
        >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
        >>> # or
        >>> op.inputs.mesh_scoping(my_mesh_scoping)
        """
        return self._mesh_scoping

    @property
    def force_averaging(self):
        """Allows to connect force_averaging input to the operator.

        Averaging on nodes is used if this pin is set
        to 1 (default is 1 for integrated
        results and 0 for discrete ones).

        Parameters
        ----------
        my_force_averaging : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal()
        >>> op.inputs.force_averaging.connect(my_force_averaging)
        >>> # or
        >>> op.inputs.force_averaging(my_force_averaging)
        """
        return self._force_averaging

    @property
    def algorithm(self):
        """Allows to connect algorithm input to the operator.

        Forces the usage of algorithm 1, 2 or 3
        (default is chosen based on the type
        of mesh).

        Parameters
        ----------
        my_algorithm : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal()
        >>> op.inputs.algorithm.connect(my_algorithm)
        >>> # or
        >>> op.inputs.algorithm(my_algorithm)
        """
        return self._algorithm


class OutputsElementalToNodal(_Outputs):
    """Intermediate class used to get outputs from
    elemental_to_nodal operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.elemental_to_nodal()
    >>> # Connect inputs : op.inputs. ...
    >>> result_field = op.outputs.field()
    """

    def __init__(self, op: Operator):
        super().__init__(elemental_to_nodal._spec().outputs, op)
        self._field = Output(elemental_to_nodal._spec().output_pin(0), 0, op)
        self._outputs.append(self._field)

    @property
    def field(self):
        """Allows to get field output of the operator

        Returns
        ----------
        my_field : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field = op.outputs.field()
        """  # noqa: E501
        return self._field



"""
serializer
==========
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class serializer(Operator):
    """Take any input and serialize them in a file.

    Parameters
    ----------
    file_path : str
    any_input1 : Any
        Any input
    any_input2 : Any
        Any input


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.serialization.serializer()

    >>> # Make input connections
    >>> my_file_path = str()
    >>> op.inputs.file_path.connect(my_file_path)
    >>> my_any_input1 = dpf.Any()
    >>> op.inputs.any_input1.connect(my_any_input1)
    >>> my_any_input2 = dpf.Any()
    >>> op.inputs.any_input2.connect(my_any_input2)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.serialization.serializer(
    ...     file_path=my_file_path,
    ...     any_input1=my_any_input1,
    ...     any_input2=my_any_input2,
    ... )

    >>> # Get output data
    >>> result_file_path = op.outputs.file_path()
    """

    def __init__(
        self, file_path=None, any_input1=None, any_input2=None, config=None, server=None
    ):
        super().__init__(name="serializer", config=config, server=server)
        self._inputs = InputsSerializer(self)
        self._outputs = OutputsSerializer(self)
        if file_path is not None:
            self.inputs.file_path.connect(file_path)
        if any_input1 is not None:
            self.inputs.any_input1.connect(any_input1)
        if any_input2 is not None:
            self.inputs.any_input2.connect(any_input2)

    @staticmethod
    def _spec():
        description = """Take any input and serialize them in a file."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="file_path",
                    type_names=["string"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="any_input",
                    type_names=["any"],
                    optional=False,
                    document="""Any input""",
                ),
                2: PinSpecification(
                    name="any_input",
                    type_names=["any"],
                    optional=False,
                    document="""Any input""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="file_path",
                    type_names=["string"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="serializer", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsSerializer
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsSerializer
        """
        return super().outputs


class InputsSerializer(_Inputs):
    """Intermediate class used to connect user inputs to
    serializer operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.serialization.serializer()
    >>> my_file_path = str()
    >>> op.inputs.file_path.connect(my_file_path)
    >>> my_any_input1 = dpf.Any()
    >>> op.inputs.any_input1.connect(my_any_input1)
    >>> my_any_input2 = dpf.Any()
    >>> op.inputs.any_input2.connect(my_any_input2)
    """

    def __init__(self, op: Operator):
        super().__init__(serializer._spec().inputs, op)
        self._file_path = Input(serializer._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._file_path)
        self._any_input1 = Input(serializer._spec().input_pin(1), 1, op, 0)
        self._inputs.append(self._any_input1)
        self._any_input2 = Input(serializer._spec().input_pin(2), 2, op, 1)
        self._inputs.append(self._any_input2)

    @property
    def file_path(self):
        """Allows to connect file_path input to the operator.

        Parameters
        ----------
        my_file_path : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.serializer()
        >>> op.inputs.file_path.connect(my_file_path)
        >>> # or
        >>> op.inputs.file_path(my_file_path)
        """
        return self._file_path

    @property
    def any_input1(self):
        """Allows to connect any_input1 input to the operator.

        Any input

        Parameters
        ----------
        my_any_input1 : Any

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.serializer()
        >>> op.inputs.any_input1.connect(my_any_input1)
        >>> # or
        >>> op.inputs.any_input1(my_any_input1)
        """
        return self._any_input1

    @property
    def any_input2(self):
        """Allows to connect any_input2 input to the operator.

        Any input

        Parameters
        ----------
        my_any_input2 : Any

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.serializer()
        >>> op.inputs.any_input2.connect(my_any_input2)
        >>> # or
        >>> op.inputs.any_input2(my_any_input2)
        """
        return self._any_input2


class OutputsSerializer(_Outputs):
    """Intermediate class used to get outputs from
    serializer operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.serialization.serializer()
    >>> # Connect inputs : op.inputs. ...
    >>> result_file_path = op.outputs.file_path()
    """

    def __init__(self, op: Operator):
        super().__init__(serializer._spec().outputs, op)
        self._file_path = Output(serializer._spec().output_pin(0), 0, op)
        self._outputs.append(self._file_path)

    @property
    def file_path(self):
        """Allows to get file_path output of the operator

        Returns
        ----------
        my_file_path : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.serializer()
        >>> # Connect inputs : op.inputs. ...
        >>> result_file_path = op.outputs.file_path()
        """  # noqa: E501
        return self._file_path



"""
scalars_to_field
================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class scalars_to_field(Operator):
    """Create scalar or vector Field.

    Parameters
    ----------
    double_or_vector_double : float, optional
        Data of the field, default is 0-field.
        specify a double to have a field of
        same value or specify directly the
        data vector.
    unit : str, optional
        Unit symbol (m, hz, kg, ...)
    location : str, optional
        Location of the field ex 'nodal',
        'elementalnodal', 'elemental'...
        default is 'numeric'.
    num_entity : int, optional
        Number of field entities. default is 1 or the
        size of the scoping in input if
        specified.
    num_comp : int, optional
        Number of field components. default is 1.
    scoping : Scoping, optional
        Scoping.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.utility.scalars_to_field()

    >>> # Make input connections
    >>> my_double_or_vector_double = float()
    >>> op.inputs.double_or_vector_double.connect(my_double_or_vector_double)
    >>> my_unit = str()
    >>> op.inputs.unit.connect(my_unit)
    >>> my_location = str()
    >>> op.inputs.location.connect(my_location)
    >>> my_num_entity = int()
    >>> op.inputs.num_entity.connect(my_num_entity)
    >>> my_num_comp = int()
    >>> op.inputs.num_comp.connect(my_num_comp)
    >>> my_scoping = dpf.Scoping()
    >>> op.inputs.scoping.connect(my_scoping)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.utility.scalars_to_field(
    ...     double_or_vector_double=my_double_or_vector_double,
    ...     unit=my_unit,
    ...     location=my_location,
    ...     num_entity=my_num_entity,
    ...     num_comp=my_num_comp,
    ...     scoping=my_scoping,
    ... )

    >>> # Get output data
    >>> result_field = op.outputs.field()
    """

    def __init__(
        self,
        double_or_vector_double=None,
        unit=None,
        location=None,
        num_entity=None,
        num_comp=None,
        scoping=None,
        config=None,
        server=None,
    ):
        super().__init__(name="fieldify", config=config, server=server)
        self._inputs = InputsScalarsToField(self)
        self._outputs = OutputsScalarsToField(self)
        if double_or_vector_double is not None:
            self.inputs.double_or_vector_double.connect(double_or_vector_double)
        if unit is not None:
            self.inputs.unit.connect(unit)
        if location is not None:
            self.inputs.location.connect(location)
        if num_entity is not None:
            self.inputs.num_entity.connect(num_entity)
        if num_comp is not None:
            self.inputs.num_comp.connect(num_comp)
        if scoping is not None:
            self.inputs.scoping.connect(scoping)

    @staticmethod
    def _spec():
        description = """Create scalar or vector Field."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="double_or_vector_double",
                    type_names=["double", "vector<double>"],
                    optional=True,
                    document="""Data of the field, default is 0-field.
        specify a double to have a field of
        same value or specify directly the
        data vector.""",
                ),
                1: PinSpecification(
                    name="unit",
                    type_names=["string"],
                    optional=True,
                    document="""Unit symbol (m, hz, kg, ...)""",
                ),
                2: PinSpecification(
                    name="location",
                    type_names=["string"],
                    optional=True,
                    document="""Location of the field ex 'nodal',
        'elementalnodal', 'elemental'...
        default is 'numeric'.""",
                ),
                3: PinSpecification(
                    name="num_entity",
                    type_names=["int32"],
                    optional=True,
                    document="""Number of field entities. default is 1 or the
        size of the scoping in input if
        specified.""",
                ),
                4: PinSpecification(
                    name="num_comp",
                    type_names=["int32"],
                    optional=True,
                    document="""Number of field components. default is 1.""",
                ),
                5: PinSpecification(
                    name="scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""Scoping.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="field",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="fieldify", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsScalarsToField
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsScalarsToField
        """
        return super().outputs


class InputsScalarsToField(_Inputs):
    """Intermediate class used to connect user inputs to
    scalars_to_field operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.scalars_to_field()
    >>> my_double_or_vector_double = float()
    >>> op.inputs.double_or_vector_double.connect(my_double_or_vector_double)
    >>> my_unit = str()
    >>> op.inputs.unit.connect(my_unit)
    >>> my_location = str()
    >>> op.inputs.location.connect(my_location)
    >>> my_num_entity = int()
    >>> op.inputs.num_entity.connect(my_num_entity)
    >>> my_num_comp = int()
    >>> op.inputs.num_comp.connect(my_num_comp)
    >>> my_scoping = dpf.Scoping()
    >>> op.inputs.scoping.connect(my_scoping)
    """

    def __init__(self, op: Operator):
        super().__init__(scalars_to_field._spec().inputs, op)
        self._double_or_vector_double = Input(
            scalars_to_field._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._double_or_vector_double)
        self._unit = Input(scalars_to_field._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._unit)
        self._location = Input(scalars_to_field._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._location)
        self._num_entity = Input(scalars_to_field._spec().input_pin(3), 3, op, -1)
        self._inputs.append(self._num_entity)
        self._num_comp = Input(scalars_to_field._spec().input_pin(4), 4, op, -1)
        self._inputs.append(self._num_comp)
        self._scoping = Input(scalars_to_field._spec().input_pin(5), 5, op, -1)
        self._inputs.append(self._scoping)

    @property
    def double_or_vector_double(self):
        """Allows to connect double_or_vector_double input to the operator.

        Data of the field, default is 0-field.
        specify a double to have a field of
        same value or specify directly the
        data vector.

        Parameters
        ----------
        my_double_or_vector_double : float

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.scalars_to_field()
        >>> op.inputs.double_or_vector_double.connect(my_double_or_vector_double)
        >>> # or
        >>> op.inputs.double_or_vector_double(my_double_or_vector_double)
        """
        return self._double_or_vector_double

    @property
    def unit(self):
        """Allows to connect unit input to the operator.

        Unit symbol (m, hz, kg, ...)

        Parameters
        ----------
        my_unit : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.scalars_to_field()
        >>> op.inputs.unit.connect(my_unit)
        >>> # or
        >>> op.inputs.unit(my_unit)
        """
        return self._unit

    @property
    def location(self):
        """Allows to connect location input to the operator.

        Location of the field ex 'nodal',
        'elementalnodal', 'elemental'...
        default is 'numeric'.

        Parameters
        ----------
        my_location : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.scalars_to_field()
        >>> op.inputs.location.connect(my_location)
        >>> # or
        >>> op.inputs.location(my_location)
        """
        return self._location

    @property
    def num_entity(self):
        """Allows to connect num_entity input to the operator.

        Number of field entities. default is 1 or the
        size of the scoping in input if
        specified.

        Parameters
        ----------
        my_num_entity : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.scalars_to_field()
        >>> op.inputs.num_entity.connect(my_num_entity)
        >>> # or
        >>> op.inputs.num_entity(my_num_entity)
        """
        return self._num_entity

    @property
    def num_comp(self):
        """Allows to connect num_comp input to the operator.

        Number of field components. default is 1.

        Parameters
        ----------
        my_num_comp : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.scalars_to_field()
        >>> op.inputs.num_comp.connect(my_num_comp)
        >>> # or
        >>> op.inputs.num_comp(my_num_comp)
        """
        return self._num_comp

    @property
    def scoping(self):
        """Allows to connect scoping input to the operator.

        Scoping.

        Parameters
        ----------
        my_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.scalars_to_field()
        >>> op.inputs.scoping.connect(my_scoping)
        >>> # or
        >>> op.inputs.scoping(my_scoping)
        """
        return self._scoping


class OutputsScalarsToField(_Outputs):
    """Intermediate class used to get outputs from
    scalars_to_field operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.scalars_to_field()
    >>> # Connect inputs : op.inputs. ...
    >>> result_field = op.outputs.field()
    """

    def __init__(self, op: Operator):
        super().__init__(scalars_to_field._spec().outputs, op)
        self._field = Output(scalars_to_field._spec().output_pin(0), 0, op)
        self._outputs.append(self._field)

    @property
    def field(self):
        """Allows to get field output of the operator

        Returns
        ----------
        my_field : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.scalars_to_field()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field = op.outputs.field()
        """  # noqa: E501
        return self._field



"""
workflow_export_json
====================
"""
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs, _modify_output_spec_with_one_type
from ansys.dpf.core.operators.specification import PinSpecification, Specification

"""Operators from "serialization" category
"""

class workflow_export_json(Operator):
    """Export a workflow in json format.

      available inputs:
        - workflow (Workflow)
        - file_path (str) (optional)

      available outputs:
        - json_workflow (DataSources ,str)

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> # Instantiate operator
      >>> op = dpf.operators.serialization.workflow_export_json()

      >>> # Make input connections
      >>> my_workflow = dpf.Workflow()
      >>> op.inputs.workflow.connect(my_workflow)
      >>> my_file_path = str()
      >>> op.inputs.file_path.connect(my_file_path)

      >>> # Instantiate operator and connect inputs in one line
      >>> op = dpf.operators.serialization.workflow_export_json(workflow=my_workflow,file_path=my_file_path)

      >>> # Get output data
      >>> result_json_workflow = op.outputs.json_workflow()"""
    def __init__(self, workflow=None, file_path=None, config=None, server=None):
        super().__init__(name="serialization::workflow_export_json", config = config, server = server)
        self._inputs = InputsWorkflowExportJson(self)
        self._outputs = OutputsWorkflowExportJson(self)
        if workflow !=None:
            self.inputs.workflow.connect(workflow)
        if file_path !=None:
            self.inputs.file_path.connect(file_path)

    @staticmethod
    def _spec():
        spec = Specification(description="""Export a workflow in json format.""",
                             map_input_pin_spec={
                                 0 : PinSpecification(name = "workflow", type_names=["workflow"], optional=False, document="""Workflow to serialize."""), 
                                 1 : PinSpecification(name = "file_path", type_names=["string"], optional=True, document="""File path to write results to. When given the operator will return a data source to the path, otherwise a json string will be output.""")},
                             map_output_pin_spec={
                                 0 : PinSpecification(name = "json_workflow", type_names=["data_sources","string"], optional=False, document="""Depending on the input of pin 1 the output will either be a data source to a json file or a json string.""")})
        return spec


    @staticmethod
    def default_config():
        return Operator.default_config(name = "serialization::workflow_export_json")

    @property
    def inputs(self):
        """Enables to connect inputs to the operator.

        Returns
        --------
        inputs : InputsWorkflowExportJson 
        """
        return super().inputs


    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it.

        Returns
        --------
        outputs : OutputsWorkflowExportJson 
        """
        return super().outputs


#internal name: serialization::workflow_export_json
#scripting name: workflow_export_json
class InputsWorkflowExportJson(_Inputs):
    """Intermediate class used to connect user inputs to workflow_export_json operator

      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.serialization.workflow_export_json()
      >>> my_workflow = dpf.Workflow()
      >>> op.inputs.workflow.connect(my_workflow)
      >>> my_file_path = str()
      >>> op.inputs.file_path.connect(my_file_path)
    """
    def __init__(self, op: Operator):
        super().__init__(workflow_export_json._spec().inputs, op)
        self._workflow = Input(workflow_export_json._spec().input_pin(0), 0, op, -1) 
        self._inputs.append(self._workflow)
        self._file_path = Input(workflow_export_json._spec().input_pin(1), 1, op, -1) 
        self._inputs.append(self._file_path)

    @property
    def workflow(self):
        """Allows to connect workflow input to the operator

        - pindoc: Workflow to serialize.

        Parameters
        ----------
        my_workflow : Workflow, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.serialization.workflow_export_json()
        >>> op.inputs.workflow.connect(my_workflow)
        >>> #or
        >>> op.inputs.workflow(my_workflow)

        """
        return self._workflow

    @property
    def file_path(self):
        """Allows to connect file_path input to the operator

        - pindoc: File path to write results to. When given the operator will return a data source to the path, otherwise a json string will be output.

        Parameters
        ----------
        my_file_path : str, 

        Examples
        --------
        >>> from ansys.dpf import core as dpf

        >>> op = dpf.operators.serialization.workflow_export_json()
        >>> op.inputs.file_path.connect(my_file_path)
        >>> #or
        >>> op.inputs.file_path(my_file_path)

        """
        return self._file_path

class OutputsWorkflowExportJson(_Outputs):
    """Intermediate class used to get outputs from workflow_export_json operator
      Examples
      --------
      >>> from ansys.dpf import core as dpf

      >>> op = dpf.operators.serialization.workflow_export_json()
      >>> # Connect inputs : op.inputs. ...
      >>> result_json_workflow = op.outputs.json_workflow()
    """
    def __init__(self, op: Operator):
        super().__init__(workflow_export_json._spec().outputs, op)
        self.json_workflow_as_data_sources = Output( _modify_output_spec_with_one_type(workflow_export_json._spec().output_pin(0), "data_sources"), 0, op) 
        self._outputs.append(self.json_workflow_as_data_sources)
        self.json_workflow_as_string = Output( _modify_output_spec_with_one_type(workflow_export_json._spec().output_pin(0), "string"), 0, op) 
        self._outputs.append(self.json_workflow_as_string)




"""Miscellaneous functions for the DPF module."""
import platform
import glob
import os

import packaging.version
import pkg_resources
import importlib
from pkgutil import iter_modules
from ansys.dpf.gate._version import __ansys_version__
from ansys.dpf.gate import load_api

DEFAULT_FILE_CHUNK_SIZE = 524288
DYNAMIC_RESULTS = True
RETURN_ARRAYS = True

RUNTIME_CLIENT_CONFIG = None


def module_exists(module_name):
    """Check if a model exists.

    Parameters
    ----------
    module_name : str
        Name of the module.

    """
    return module_name in (name for loader, name, ispkg in iter_modules())


def is_float(string):
    """Check if a string can be converted to a float.

    Parameters
    ----------
    string : str
       String to check.

    Returns
    -------
    bool
        ``True`` if the input can be converted to a float, ``False`` if otherwise.
    """
    try:
        float(string)
        return True
    except ValueError:
        return False


def is_ubuntu():
    """Check if the operating system is Ubuntu.

    Returns
    -------
    bool
        ``True`` when the operating system is Ubuntu, ``False`` if otherwise.
    """
    if os.name == "posix":
        return "ubuntu" in platform.platform().lower()
    return False


def get_ansys_path(ansys_path=None):
    """Give input path back if given, else look for ANSYS_DPF_PATH,
    then among AWP_ROOT and installed ansys-dpf-server modules to take the latest available.

    Parameters
    ----------
    ansys_path : str
        Full path to an Ansys installation to use.

    Returns
    -------
    ansys_path : str
        Full path to an Ansys installation.

    """
    # If no custom path was given in input
    # First check the environment variable for a custom path
    if ansys_path is None:
        ansys_path = os.environ.get("ANSYS_DPF_PATH")
    # Then check for usual installation folders with AWP_ROOT and installed modules
    if ansys_path is None:
        ansys_path = find_ansys()
    # If still no install has been found, throw an exception
    if ansys_path is None:
        raise ValueError(
            "Unable to locate any Ansys installation.\n"
            f'Make sure the "AWP_ROOT{__ansys_version__}" environment variable '
            f"is set if using ANSYS version {__ansys_version__}.\n"
            "You can also manually define the path to the ANSYS installation root folder"
            " of the version you want to use (vXXX folder):\n"
            '- when starting the server with "start_local_server(ansys_path=*/vXXX)"\n'
            '- or by setting it by default with the environment variable "ANSYS_DPF_PATH"'
        )
    return ansys_path


def _pythonize_awp_version(version):
    if len(version) != 3:
        return version
    return "20" + version[0:2] + "." + version[2]


def _find_latest_ansys_versions():
    if hasattr(load_api, "_find_latest_ansys_versions"):
        return load_api._find_latest_ansys_versions()
    awp_versions = [key[-3:] for key in os.environ.keys() if "AWP_ROOT" in key]
    installed_packages_list = {}

    for awp_version in awp_versions:
        if not awp_version.isnumeric():
            continue
        ansys_path = os.environ.get("AWP_ROOT" + awp_version)
        if ansys_path:
            installed_packages_list[
                packaging.version.parse(_pythonize_awp_version(awp_version))
            ] = ansys_path

    installed_packages = pkg_resources.working_set
    for i in installed_packages:
        if "ansys-dpf-server" in i.key:
            file_name = pkg_resources.to_filename(i.project_name.replace("ansys-dpf-", ""))
            try:
                module = importlib.import_module("ansys.dpf." + file_name)
                installed_packages_list[
                    packaging.version.parse(module.__version__)
                ] = module.__path__[0]
            except ModuleNotFoundError:
                pass
            except AttributeError:
                pass
    if len(installed_packages_list) > 0:
        return installed_packages_list[sorted(installed_packages_list)[-1]]


def find_ansys():
    """Search for a standard ANSYS environment variable (AWP_ROOTXXX) or a standard installation
    location to find the path to the latest Ansys installation.

    Returns
    -------
    ansys_path : str
        Full path to the latest version of the Ansys installation.

    Examples
    --------
    Return path of latest Ansys version on Windows.

    >>> from ansys.dpf.core.misc import find_ansys
    >>> path = find_ansys()

    Return path of latest Ansys version on Linux.

    >>> path = find_ansys()

    """
    latest_install = _find_latest_ansys_versions()
    if latest_install:
        return latest_install

    base_path = None
    if os.name == "nt":
        base_path = os.path.join(os.environ["PROGRAMFILES"], "ANSYS INC")
    elif os.name == "posix":
        for path in ["/usr/ansys_inc", "/ansys_inc"]:
            if os.path.isdir(path):
                base_path = path
    else:
        raise OSError(f"Unsupported OS {os.name}")

    if base_path is None:
        return base_path

    paths = glob.glob(os.path.join(base_path, "v*"))

    if not paths:
        return None

    versions = {}
    for path in paths:
        ver_str = path[-3:]
        if is_float(ver_str):
            versions[int(ver_str)] = path

    return versions[max(versions.keys())]


def is_pypim_configured():
    """Check if the environment is configured for PyPIM, without using pypim.
    This method is equivalent to ansys.platform.instancemanagement.is_configured(). It's
    reproduced here to avoid having hard dependencies.
    Returns
    -------
    bool
        ``True`` if the environment is setup to use the PIM API, ``False`` otherwise.
    """
    return "ANSYS_PLATFORM_INSTANCEMANAGEMENT_CONFIG" in os.environ



"""
.. _ref_examples:

Result Files Examples
=====================
Examples result files.
"""

import os
import inspect

from ansys.dpf.core import server as server_module
from ansys.dpf.core.core import upload_file_in_tmp_folder
from ansys.dpf.core import path_utilities
from ansys.dpf.core import DataSources

if os.environ.get("DPF_DOCKER", "").lower() == "true":
    # must pass a path that can be accessed by a docker image with
    # this directory mounted at the repository level for CI
    _module_path = r"/dpf/ansys/dpf/core/examples/"
else:
    _module_path = os.path.dirname(inspect.getfile(inspect.currentframe()))

# this files can be imported with from `ansys.dpf.core import examples`:
simple_bar = os.path.join(_module_path, "ASimpleBar.rst")
static_rst = os.path.join(_module_path, "static.rst")
complex_rst = os.path.join(_module_path, "complex.rst")
multishells_rst = os.path.join(_module_path, "model_with_ns.rst")
electric_therm = os.path.join(_module_path, "rth", "rth_electric.rth")
steady_therm = os.path.join(_module_path, "rth", "rth_steady.rth")
transient_therm = os.path.join(_module_path, "rth", "rth_transient.rth")
msup_transient = os.path.join(_module_path, "msup_transient_plate1.rst")
simple_cyclic = os.path.join(_module_path, "file_cyclic.rst")
distributed_msup_folder = os.path.join(_module_path, "msup_distributed")


def get_example_required_minimum_dpf_version(file: os.PathLike) -> str:
    """Returns the minimal DPF server version required to run the example, as declared in a note.

    Parameters
    ----------
    file:
        Path to the example file in question.

    Returns
    -------
    Returns the minimal DPF server version required.
    """
    # Read the minimal server version required for the example
    header_flag = '"""'
    note_flag = r".. note::"
    version_flag = "This example requires DPF"
    in_header = False
    previous_line_is_note = False
    minimum_version_str = "0.0"
    with open(file, "r") as f:
        for line in f:
            if line[:3] == header_flag:
                if not in_header:
                    in_header = True
                    continue
                else:
                    break
            if (version_flag in line) and previous_line_is_note and in_header:
                minimum_version_str = line.strip(version_flag).split()[0]
                break
            if note_flag in line:
                previous_line_is_note = True
            else:
                previous_line_is_note = False
    return minimum_version_str


def find_files(local_path, should_upload=True, server=None, return_local_path=False):
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    local_path : str
        File path to make available server side.
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.
    """
    if return_local_path:
        return local_path
    if should_upload:
        server = server_module.get_or_create_server(server)
        if not server.local_server and not server.docker_config.use_docker:
            return upload_file_in_tmp_folder(local_path, server=server)

    return path_utilities.to_server_os(local_path, server)


def find_simple_bar(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_simple_bar()
    >>> path
    'C:/Users/user/AppData/local/temp/ASimpleBar.rst'

    """
    return find_files(simple_bar, should_upload, server, return_local_path)


def find_static_rst(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_static_rst()
    >>> path
    'C:/Users/user/AppData/local/temp/static.rst'

    """
    return find_files(static_rst, should_upload, server, return_local_path)


def find_complex_rst(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_complex_rst()
    >>> path
    'C:/Users/user/AppData/local/temp/complex.rst'

    """
    return find_files(complex_rst, should_upload, server, return_local_path)


def find_multishells_rst(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_multishells_rst()
    >>> path
    'C:/Users/user/AppData/local/temp/model_with_ns.rst'

    """
    return find_files(multishells_rst, should_upload, server, return_local_path)


def find_electric_therm(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_electric_therm()
    >>> path
    'C:/Users/user/AppData/local/temp/rth_electric.rth'

    """
    return find_files(electric_therm, should_upload, server, return_local_path)


def find_steady_therm(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_steady_therm()
    >>> path
    'C:/Users/user/AppData/local/temp/rth_steady.rst'

    """
    return find_files(steady_therm, should_upload, server, return_local_path)


def find_transient_therm(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_transient_therm()
    >>> path
    'C:/Users/user/AppData/local/temp/rth_transient.rst'

    """
    return find_files(transient_therm, should_upload, server, return_local_path)


def find_msup_transient(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_msup_transient()
    >>> path
    'C:/Users/user/AppData/local/temp/msup_transient_plate1.rst'

    """
    return find_files(msup_transient, should_upload, server, return_local_path)


def find_simple_cyclic(should_upload: bool = True, server=None, return_local_path=False) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_simple_cyclic()
    >>> path
    'C:/Users/user/AppData/local/temp/file_cyclic.rst'

    """
    return find_files(simple_cyclic, should_upload, server, return_local_path)


def find_distributed_msup_folder(
    should_upload: bool = True, server=None, return_local_path=False
) -> str:
    """Make the result file available server side, if the server is remote the file is uploaded
    server side. Returns the path on the file.

    Parameters
    ----------
    should_upload : bool, optional (default True)
        Whether the file should be uploaded server side when the server is remote.
    server : server.DPFServer, optional
        Server with channel connected to the remote or local instance. When
        ``None``, attempts to use the global server.
    return_local_path: bool, optional
        If ``True``, the local path is returned as is, without uploading, nor searching
        for mounted volumes.

    Returns
    -------
    str
        Path to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> path = examples.find_distributed_msup_folder()
    >>> path
    'C:/Users/user/AppData/local/temp/msup_distributed'

    """
    return find_files(distributed_msup_folder, should_upload, server, return_local_path)


def fluid_axial_model() -> DataSources:
    """Download the files and create a DataSources.

    Returns
    -------
    DataSources
        DataSources to the example file.

    Examples
    --------

    >>> from ansys.dpf.core import examples
    >>> ds = examples.fluid_axial_model()
    """
    from .downloads import download_fluent_axial_comp

    aux = download_fluent_axial_comp()
    ds = DataSources()
    ds.set_result_file_path(aux["cas"][0], "cas")
    ds.add_file_path(aux["dat"][0], "dat")
    return ds



"""
cyclic_expanded_enf
===================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class cyclic_expanded_enf(Operator):
    """Read ENF from an rst file and expand it with cyclic symmetry.

    Parameters
    ----------
    time_scoping : Scoping, optional
    mesh_scoping : ScopingsContainer or Scoping, optional
    fields_container : FieldsContainer, optional
        Fieldscontainer already allocated modified
        inplace
    streams_container : StreamsContainer or Stream, optional
        Streams containing the result file.
    data_sources : DataSources
        Data sources containing the result file.
    bool_rotate_to_global : bool, optional
        Default is true
    all_dofs : bool, optional
        If this pin is set to true, all the dofs are
        retrieved. by default this pin is set
        to false and only the translational
        dofs are retrieved.
    sector_mesh : MeshedRegion or MeshesContainer, optional
        Mesh of the base sector (can be a skin).
    requested_location : str, optional
        Location needed in output
    read_cyclic : int, optional
        If 0 cyclic symmetry is ignored, if 1 cyclic
        sector is read, if 2 cyclic expansion
        is done, if 3 cyclic expansion is
        done and stages are merged (default
        is 1)
    expanded_meshed_region : MeshedRegion or MeshesContainer, optional
        Mesh expanded.
    cyclic_support : CyclicSupport, optional
    sectors_to_expand : Scoping or ScopingsContainer, optional
        Sectors to expand (start at 0), for
        multistage: use scopings container
        with 'stage' label.
    phi : float, optional
        Phi angle (default value 0.0)


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.result.cyclic_expanded_enf()

    >>> # Make input connections
    >>> my_time_scoping = dpf.Scoping()
    >>> op.inputs.time_scoping.connect(my_time_scoping)
    >>> my_mesh_scoping = dpf.ScopingsContainer()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_bool_rotate_to_global = bool()
    >>> op.inputs.bool_rotate_to_global.connect(my_bool_rotate_to_global)
    >>> my_all_dofs = bool()
    >>> op.inputs.all_dofs.connect(my_all_dofs)
    >>> my_sector_mesh = dpf.MeshedRegion()
    >>> op.inputs.sector_mesh.connect(my_sector_mesh)
    >>> my_requested_location = str()
    >>> op.inputs.requested_location.connect(my_requested_location)
    >>> my_read_cyclic = int()
    >>> op.inputs.read_cyclic.connect(my_read_cyclic)
    >>> my_expanded_meshed_region = dpf.MeshedRegion()
    >>> op.inputs.expanded_meshed_region.connect(my_expanded_meshed_region)
    >>> my_cyclic_support = dpf.CyclicSupport()
    >>> op.inputs.cyclic_support.connect(my_cyclic_support)
    >>> my_sectors_to_expand = dpf.Scoping()
    >>> op.inputs.sectors_to_expand.connect(my_sectors_to_expand)
    >>> my_phi = float()
    >>> op.inputs.phi.connect(my_phi)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.result.cyclic_expanded_enf(
    ...     time_scoping=my_time_scoping,
    ...     mesh_scoping=my_mesh_scoping,
    ...     fields_container=my_fields_container,
    ...     streams_container=my_streams_container,
    ...     data_sources=my_data_sources,
    ...     bool_rotate_to_global=my_bool_rotate_to_global,
    ...     all_dofs=my_all_dofs,
    ...     sector_mesh=my_sector_mesh,
    ...     requested_location=my_requested_location,
    ...     read_cyclic=my_read_cyclic,
    ...     expanded_meshed_region=my_expanded_meshed_region,
    ...     cyclic_support=my_cyclic_support,
    ...     sectors_to_expand=my_sectors_to_expand,
    ...     phi=my_phi,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    >>> result_expanded_meshes = op.outputs.expanded_meshes()
    """

    def __init__(
        self,
        time_scoping=None,
        mesh_scoping=None,
        fields_container=None,
        streams_container=None,
        data_sources=None,
        bool_rotate_to_global=None,
        all_dofs=None,
        sector_mesh=None,
        requested_location=None,
        read_cyclic=None,
        expanded_meshed_region=None,
        cyclic_support=None,
        sectors_to_expand=None,
        phi=None,
        config=None,
        server=None,
    ):
        super().__init__(name="mapdl::rst::ENF_cyclic", config=config, server=server)
        self._inputs = InputsCyclicExpandedEnf(self)
        self._outputs = OutputsCyclicExpandedEnf(self)
        if time_scoping is not None:
            self.inputs.time_scoping.connect(time_scoping)
        if mesh_scoping is not None:
            self.inputs.mesh_scoping.connect(mesh_scoping)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if streams_container is not None:
            self.inputs.streams_container.connect(streams_container)
        if data_sources is not None:
            self.inputs.data_sources.connect(data_sources)
        if bool_rotate_to_global is not None:
            self.inputs.bool_rotate_to_global.connect(bool_rotate_to_global)
        if all_dofs is not None:
            self.inputs.all_dofs.connect(all_dofs)
        if sector_mesh is not None:
            self.inputs.sector_mesh.connect(sector_mesh)
        if requested_location is not None:
            self.inputs.requested_location.connect(requested_location)
        if read_cyclic is not None:
            self.inputs.read_cyclic.connect(read_cyclic)
        if expanded_meshed_region is not None:
            self.inputs.expanded_meshed_region.connect(expanded_meshed_region)
        if cyclic_support is not None:
            self.inputs.cyclic_support.connect(cyclic_support)
        if sectors_to_expand is not None:
            self.inputs.sectors_to_expand.connect(sectors_to_expand)
        if phi is not None:
            self.inputs.phi.connect(phi)

    @staticmethod
    def _spec():
        description = (
            """Read ENF from an rst file and expand it with cyclic symmetry."""
        )
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="time_scoping",
                    type_names=["scoping", "vector<int32>"],
                    optional=True,
                    document="""""",
                ),
                1: PinSpecification(
                    name="mesh_scoping",
                    type_names=["scopings_container", "scoping", "vector<int32>"],
                    optional=True,
                    document="""""",
                ),
                2: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=True,
                    document="""Fieldscontainer already allocated modified
        inplace""",
                ),
                3: PinSpecification(
                    name="streams_container",
                    type_names=["streams_container", "stream"],
                    optional=True,
                    document="""Streams containing the result file.""",
                ),
                4: PinSpecification(
                    name="data_sources",
                    type_names=["data_sources"],
                    optional=False,
                    document="""Data sources containing the result file.""",
                ),
                5: PinSpecification(
                    name="bool_rotate_to_global",
                    type_names=["bool"],
                    optional=True,
                    document="""Default is true""",
                ),
                6: PinSpecification(
                    name="all_dofs",
                    type_names=["bool"],
                    optional=True,
                    document="""If this pin is set to true, all the dofs are
        retrieved. by default this pin is set
        to false and only the translational
        dofs are retrieved.""",
                ),
                7: PinSpecification(
                    name="sector_mesh",
                    type_names=["abstract_meshed_region", "meshes_container"],
                    optional=True,
                    document="""Mesh of the base sector (can be a skin).""",
                ),
                9: PinSpecification(
                    name="requested_location",
                    type_names=["string"],
                    optional=True,
                    document="""Location needed in output""",
                ),
                14: PinSpecification(
                    name="read_cyclic",
                    type_names=["enum dataProcessing::ECyclicReading", "int32"],
                    optional=True,
                    document="""If 0 cyclic symmetry is ignored, if 1 cyclic
        sector is read, if 2 cyclic expansion
        is done, if 3 cyclic expansion is
        done and stages are merged (default
        is 1)""",
                ),
                15: PinSpecification(
                    name="expanded_meshed_region",
                    type_names=["abstract_meshed_region", "meshes_container"],
                    optional=True,
                    document="""Mesh expanded.""",
                ),
                16: PinSpecification(
                    name="cyclic_support",
                    type_names=["cyclic_support"],
                    optional=True,
                    document="""""",
                ),
                18: PinSpecification(
                    name="sectors_to_expand",
                    type_names=["vector<int32>", "scoping", "scopings_container"],
                    optional=True,
                    document="""Sectors to expand (start at 0), for
        multistage: use scopings container
        with 'stage' label.""",
                ),
                19: PinSpecification(
                    name="phi",
                    type_names=["double"],
                    optional=True,
                    document="""Phi angle (default value 0.0)""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""Fieldscontainer filled in""",
                ),
                1: PinSpecification(
                    name="expanded_meshes",
                    type_names=["meshes_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="mapdl::rst::ENF_cyclic", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsCyclicExpandedEnf
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsCyclicExpandedEnf
        """
        return super().outputs


class InputsCyclicExpandedEnf(_Inputs):
    """Intermediate class used to connect user inputs to
    cyclic_expanded_enf operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.cyclic_expanded_enf()
    >>> my_time_scoping = dpf.Scoping()
    >>> op.inputs.time_scoping.connect(my_time_scoping)
    >>> my_mesh_scoping = dpf.ScopingsContainer()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_bool_rotate_to_global = bool()
    >>> op.inputs.bool_rotate_to_global.connect(my_bool_rotate_to_global)
    >>> my_all_dofs = bool()
    >>> op.inputs.all_dofs.connect(my_all_dofs)
    >>> my_sector_mesh = dpf.MeshedRegion()
    >>> op.inputs.sector_mesh.connect(my_sector_mesh)
    >>> my_requested_location = str()
    >>> op.inputs.requested_location.connect(my_requested_location)
    >>> my_read_cyclic = int()
    >>> op.inputs.read_cyclic.connect(my_read_cyclic)
    >>> my_expanded_meshed_region = dpf.MeshedRegion()
    >>> op.inputs.expanded_meshed_region.connect(my_expanded_meshed_region)
    >>> my_cyclic_support = dpf.CyclicSupport()
    >>> op.inputs.cyclic_support.connect(my_cyclic_support)
    >>> my_sectors_to_expand = dpf.Scoping()
    >>> op.inputs.sectors_to_expand.connect(my_sectors_to_expand)
    >>> my_phi = float()
    >>> op.inputs.phi.connect(my_phi)
    """

    def __init__(self, op: Operator):
        super().__init__(cyclic_expanded_enf._spec().inputs, op)
        self._time_scoping = Input(cyclic_expanded_enf._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._time_scoping)
        self._mesh_scoping = Input(cyclic_expanded_enf._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._mesh_scoping)
        self._fields_container = Input(
            cyclic_expanded_enf._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._fields_container)
        self._streams_container = Input(
            cyclic_expanded_enf._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._streams_container)
        self._data_sources = Input(cyclic_expanded_enf._spec().input_pin(4), 4, op, -1)
        self._inputs.append(self._data_sources)
        self._bool_rotate_to_global = Input(
            cyclic_expanded_enf._spec().input_pin(5), 5, op, -1
        )
        self._inputs.append(self._bool_rotate_to_global)
        self._all_dofs = Input(cyclic_expanded_enf._spec().input_pin(6), 6, op, -1)
        self._inputs.append(self._all_dofs)
        self._sector_mesh = Input(cyclic_expanded_enf._spec().input_pin(7), 7, op, -1)
        self._inputs.append(self._sector_mesh)
        self._requested_location = Input(
            cyclic_expanded_enf._spec().input_pin(9), 9, op, -1
        )
        self._inputs.append(self._requested_location)
        self._read_cyclic = Input(cyclic_expanded_enf._spec().input_pin(14), 14, op, -1)
        self._inputs.append(self._read_cyclic)
        self._expanded_meshed_region = Input(
            cyclic_expanded_enf._spec().input_pin(15), 15, op, -1
        )
        self._inputs.append(self._expanded_meshed_region)
        self._cyclic_support = Input(
            cyclic_expanded_enf._spec().input_pin(16), 16, op, -1
        )
        self._inputs.append(self._cyclic_support)
        self._sectors_to_expand = Input(
            cyclic_expanded_enf._spec().input_pin(18), 18, op, -1
        )
        self._inputs.append(self._sectors_to_expand)
        self._phi = Input(cyclic_expanded_enf._spec().input_pin(19), 19, op, -1)
        self._inputs.append(self._phi)

    @property
    def time_scoping(self):
        """Allows to connect time_scoping input to the operator.

        Parameters
        ----------
        my_time_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.time_scoping.connect(my_time_scoping)
        >>> # or
        >>> op.inputs.time_scoping(my_time_scoping)
        """
        return self._time_scoping

    @property
    def mesh_scoping(self):
        """Allows to connect mesh_scoping input to the operator.

        Parameters
        ----------
        my_mesh_scoping : ScopingsContainer or Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
        >>> # or
        >>> op.inputs.mesh_scoping(my_mesh_scoping)
        """
        return self._mesh_scoping

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Fieldscontainer already allocated modified
        inplace

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def streams_container(self):
        """Allows to connect streams_container input to the operator.

        Streams containing the result file.

        Parameters
        ----------
        my_streams_container : StreamsContainer or Stream

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.streams_container.connect(my_streams_container)
        >>> # or
        >>> op.inputs.streams_container(my_streams_container)
        """
        return self._streams_container

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator.

        Data sources containing the result file.

        Parameters
        ----------
        my_data_sources : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> # or
        >>> op.inputs.data_sources(my_data_sources)
        """
        return self._data_sources

    @property
    def bool_rotate_to_global(self):
        """Allows to connect bool_rotate_to_global input to the operator.

        Default is true

        Parameters
        ----------
        my_bool_rotate_to_global : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.bool_rotate_to_global.connect(my_bool_rotate_to_global)
        >>> # or
        >>> op.inputs.bool_rotate_to_global(my_bool_rotate_to_global)
        """
        return self._bool_rotate_to_global

    @property
    def all_dofs(self):
        """Allows to connect all_dofs input to the operator.

        If this pin is set to true, all the dofs are
        retrieved. by default this pin is set
        to false and only the translational
        dofs are retrieved.

        Parameters
        ----------
        my_all_dofs : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.all_dofs.connect(my_all_dofs)
        >>> # or
        >>> op.inputs.all_dofs(my_all_dofs)
        """
        return self._all_dofs

    @property
    def sector_mesh(self):
        """Allows to connect sector_mesh input to the operator.

        Mesh of the base sector (can be a skin).

        Parameters
        ----------
        my_sector_mesh : MeshedRegion or MeshesContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.sector_mesh.connect(my_sector_mesh)
        >>> # or
        >>> op.inputs.sector_mesh(my_sector_mesh)
        """
        return self._sector_mesh

    @property
    def requested_location(self):
        """Allows to connect requested_location input to the operator.

        Location needed in output

        Parameters
        ----------
        my_requested_location : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.requested_location.connect(my_requested_location)
        >>> # or
        >>> op.inputs.requested_location(my_requested_location)
        """
        return self._requested_location

    @property
    def read_cyclic(self):
        """Allows to connect read_cyclic input to the operator.

        If 0 cyclic symmetry is ignored, if 1 cyclic
        sector is read, if 2 cyclic expansion
        is done, if 3 cyclic expansion is
        done and stages are merged (default
        is 1)

        Parameters
        ----------
        my_read_cyclic : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.read_cyclic.connect(my_read_cyclic)
        >>> # or
        >>> op.inputs.read_cyclic(my_read_cyclic)
        """
        return self._read_cyclic

    @property
    def expanded_meshed_region(self):
        """Allows to connect expanded_meshed_region input to the operator.

        Mesh expanded.

        Parameters
        ----------
        my_expanded_meshed_region : MeshedRegion or MeshesContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.expanded_meshed_region.connect(my_expanded_meshed_region)
        >>> # or
        >>> op.inputs.expanded_meshed_region(my_expanded_meshed_region)
        """
        return self._expanded_meshed_region

    @property
    def cyclic_support(self):
        """Allows to connect cyclic_support input to the operator.

        Parameters
        ----------
        my_cyclic_support : CyclicSupport

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.cyclic_support.connect(my_cyclic_support)
        >>> # or
        >>> op.inputs.cyclic_support(my_cyclic_support)
        """
        return self._cyclic_support

    @property
    def sectors_to_expand(self):
        """Allows to connect sectors_to_expand input to the operator.

        Sectors to expand (start at 0), for
        multistage: use scopings container
        with 'stage' label.

        Parameters
        ----------
        my_sectors_to_expand : Scoping or ScopingsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.sectors_to_expand.connect(my_sectors_to_expand)
        >>> # or
        >>> op.inputs.sectors_to_expand(my_sectors_to_expand)
        """
        return self._sectors_to_expand

    @property
    def phi(self):
        """Allows to connect phi input to the operator.

        Phi angle (default value 0.0)

        Parameters
        ----------
        my_phi : float

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> op.inputs.phi.connect(my_phi)
        >>> # or
        >>> op.inputs.phi(my_phi)
        """
        return self._phi


class OutputsCyclicExpandedEnf(_Outputs):
    """Intermediate class used to get outputs from
    cyclic_expanded_enf operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.cyclic_expanded_enf()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    >>> result_expanded_meshes = op.outputs.expanded_meshes()
    """

    def __init__(self, op: Operator):
        super().__init__(cyclic_expanded_enf._spec().outputs, op)
        self._fields_container = Output(
            cyclic_expanded_enf._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._fields_container)
        self._expanded_meshes = Output(cyclic_expanded_enf._spec().output_pin(1), 1, op)
        self._outputs.append(self._expanded_meshes)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container

    @property
    def expanded_meshes(self):
        """Allows to get expanded_meshes output of the operator

        Returns
        ----------
        my_expanded_meshes : MeshesContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.cyclic_expanded_enf()
        >>> # Connect inputs : op.inputs. ...
        >>> result_expanded_meshes = op.outputs.expanded_meshes()
        """  # noqa: E501
        return self._expanded_meshes
